@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Parse the UCI Bach choral harmony data set
 
-our $VERSION = '0.0302';
+our $VERSION = '0.0400';
 
 use Moo;
 use strictures 2;
@@ -231,6 +231,42 @@ sub search {
     return \%results;
 }
 
+
+sub bits2notes {
+    my ( $self, $string, $accidental ) = @_;
+
+    $accidental ||= 'b';
+
+    my @notes = ();
+
+    no warnings 'qw';
+    my @positions = qw( C C#|Db D D#|Eb E F F#|Gb G G#|Ab A A#|Bb B );
+
+    my @bits = split //, $string;
+
+    my $i = 0;
+
+    for my $bit ( @bits ) {
+        if ( $bit ) {
+            my @note = split /\|/, $positions[$i];
+            my $note = '';
+
+            if ( @note > 1 ) {
+                $note = $accidental eq '#' ? $note[0] : $note[1];
+            }
+            else {
+                $note = $note[0];
+            }
+
+            push @notes, $note;
+        }
+
+        $i++;
+    }
+
+    return \@notes;
+}
+
 sub _search_param {
     my ( $self, $name, $param, $seen ) = @_;
 
@@ -307,7 +343,7 @@ Music::BachChoralHarmony - Parse the UCI Bach choral harmony data set
 
 =head1 VERSION
 
-version 0.0302
+version 0.0400
 
 =head1 SYNOPSIS
 
@@ -337,6 +373,12 @@ version 0.0302
   # Args can be combined too:
   $songs = $bach->search( key => 'C_M C_m', chord => 'X_m & F_M' );
 
+  # Possibly handy:
+  my $notes = $bach->bits2notes('100000000000');     # C
+  $notes = $bach->bits2notes('010000000000');        # Db
+  $notes = $bach->bits2notes( '010000000000', '#' ); # C#
+  $notes = $bach->bits2notes( '100000000010', '#' ); # C A#
+
 =head1 DESCRIPTION
 
 C<Music::BachChoralHarmony> parses the UCI Bach choral harmony data set of 60
@@ -417,7 +459,7 @@ The dataset B<notes> bit-string is defined by position as follows:
   11 => B
 
 So if a C<C> note is present, the C<0>th bit will be set to C<1>,
-otherwise C<0>.  If A C<Bb> note is present, the C<10>th bit will be
+otherwise C<0>.  If a C<Bb> note is present, the C<10>th bit will be
 set, etc.
 
 =head2 search
@@ -438,6 +480,38 @@ The B<bass>, B<chord>, and B<notes> can be searched either as C<or>
 (separating note names with a space character), or as inclusive C<and>
 (separating note names with an C<&> character).
 
+=head2 bits2notes
+
+  $bach->bits2notes($string);
+  $bach->bits2notes( $string, $accidental );
+
+Convert a bit-string of 12 binary positions to a note list array
+reference.
+
+The B<accidental> can be given as C<#> sharp or C<b> flat the case of
+enharmonic notes.
+
+Default: C<b>
+
+The dataset B<notes> bit-string is defined by position as follows:
+
+  0  => C
+  1  => C# or Db
+  2  => D
+  3  => D# or Eb
+  4  => E
+  5  => F
+  6  => F# or Gb
+  7  => G
+  8  => G# or Ab
+  9  => A
+  10 => A# or Bb
+  11 => B
+
+So if a C<C> note is present in the current phrase, the first bit will
+be set to C<1>, otherwise C<0>.  If a C<Bb> note is present, the
+penultimate bit will be set, etc.
+
 =head1 SEE ALSO
 
 The F<eg/*> and F<t/01-methods.t> files in this distribution.
